/*
 * Licensed Materials - Property of IBM,
 * (c) Copyright IBM Corp. 2005, 2010  All Rights Reserved.
 */

package com.ibm.lang.management;

/**
 * The IBM-specific interface for monitoring the operating system where the
 * virtual machine is running.
 * 
 * @author gharley
 * @since 1.5
 */
public interface OperatingSystemMXBean extends
        java.lang.management.OperatingSystemMXBean {

    /**
     * Returns the total number of bytes used for physical memory.
     * 
     * @return the number of bytes used for physical memory
     */
    public long getTotalPhysicalMemory();

    /**
     * Returns the collective capacity of the virtual processors in
     * the partition the VM is running in. The value returned is in
     * units of 1% of a physical processor's capacity, so a value of
     * 100 is equal to 1 physical processor. In environments without
     * such partitioning support, this call will return
     * getAvailableProcessors() * 100.
     * 
     * @return the collective capacity of the virtual processors available
     * to the VM
     */
    public int getProcessingCapacity();

    /**
     * Returns total amount of time the process has been scheduled or
     * executed so far in both kernel and user modes. Returns -1 if the
     * value is unavailable on this platform or in the case of an error.
     *
     * @return process cpu time in 100 ns units
     */
    public long getProcessCpuTime();
    
    /**
     * Returns total amount of time the process has been scheduled or
     * executed so far in both kernel and user modes. Returns -1 if the
     * value is unavailable on this platform or in the case of an error.
     *
     * @return process cpu time in ns units
     */
    public long getProcessCpuTimeByNS();

    /**
     * Returns the amount of physical memory that is available on the
     * system in bytes. Returns -1 if the value is unavailable on this
     * platform or in the case of an error.
     *
     * @return amount of physical memory available in bytes
     */
    public long getFreePhysicalMemorySize();

    /**
     * Returns the amount of virtual memory used by the process in bytes,
     * including physical memory and swap space. Returns -1 if the value
     * is unavailable on this platform or in the case of an error.
     *
     * @return amount of virtual memory used by the process in bytes
     */
    public long getProcessVirtualMemorySize();

    /**
     * Returns the amount of private memory used by the process in bytes.
     * Returns -1 if the value is unavailable on this platform or in the
     * case of an error.
     *
     * @return amount of private memory used by the process in bytes
     */
    public long getProcessPrivateMemorySize();

    /**
     * Returns the amount of physical memory being used by the process
     * in bytes. Returns -1 if the value is unavailable on this platform
     * or in the case of an error.
     *
     * @return amount of physical memory being used by the process in bytes
     */
    public long getProcessPhysicalMemorySize();

}

/*
 * $Log$
 * Revision 1.5  2005/05/12 00:34:50  pschurch
 * add getProcessingCapacity
 *
 * Revision 1.4  2005/04/18 10:39:42  gharley
 * Removal of all attributes bar PhysicalMemory from the proprietary interface. Agreed with Paul Church and Tim Preece.
 *
 * Revision 1.3  2005/02/24 16:47:35  gharley
 * Incorrect method name. Replaced getCommittedPhysicalMemory with the
 * method called getCommittedVirtualMemory
 *
 * Revision 1.2  2005/02/14 13:21:05  gharley
 * D'oh ! The extension interface ought to extend the standard interface.
 * Revision 1.1 2005/02/14 12:10:18 gharley
 * Initial implementation.
 * 
 */
